@@ -10,8 +10,9 @@ class Grammar
 {
     typedef std::set<Symbol const *> SymbolSet;
 
-    SymbolSet    d_derivable;
-    SymbolSet    d_inspecting;
+    SymbolSet    d_derivable;           // used when testing whether the start
+                                        // symbol derives any sentences
+    SymbolSet    d_inspecting;          // (same, see derivable.cc)
 
     public:
         void deriveSentence();
