@@ -3,8 +3,8 @@
 void Parser::noDefaultTypeWarning()
 {
     if (d_unionDeclared)
-        lineMsg() << "In production rule \n"<< 
+        lineMsg(wmsg) << "In production rule \n"<< 
                             "\t`" << &d_rules.lastProduction() << " '\n"
                             "\t`" << d_rules.name() << "' has no default "
-                                        "($$) type-association" << warning;
+                                        "($$) type-association" << endl;
 }
