@@ -6,5 +6,5 @@ void Rules::showUnusedTerminals() const
 
     for_each(d_terminal.begin(), d_terminal.end(), &Terminal::unused);
     
-    Msg::setWarning();
+    wmsg.setTag("Warning");
 }
