@@ -3,8 +3,8 @@
 bool Scanner::popSource(yy_buffer_state *current)
 {
     if (d_block)                // an open block exists at EOF
-        lineMsg() << "EOF: Incomplete compound statement "
-                    "starts at Line " << d_block.line() << fatal;
+        lineMsg(fmsg) << "EOF: Incomplete compound statement "
+                    "starts at Line " << d_block.line() << endl;
 
     if (d_state.empty())
         return false;
