@@ -23,7 +23,7 @@
 // Conflicts are inspected for all reduction elements, so for index element 0
 // in the above example, as follows:
 // 
-//     1. The nextVector's symbols are search in the LA set of the reduction
+//     1. The nextVector's symbols are searched in the LA set of the reduction
 //        item (so, subsequently '+', '-', '*' and '/' are searched in the LA
 //        set of itemVector[0].
 //     2. In this case, all are found and depending on the token's priority
@@ -32,24 +32,40 @@
 //  Production rules received their priority setting either explicitly (using
 //  %prec) or from their first terminal token. See also 
 //  rules/updateprecedences.cc
+//
+//  What happens if neither occurs? In a rule like 'expr: term' there is no
+//  first terminal token and there is no %prec being used. 
+//  In these cases the rule automatically receives the highest precedence and 
+//  a shift/reduce conflict is rapported (as pointed out by Ramanand
+//  Mandayam).
 
-void SRConflict::visitReduction(size_t idx, SRConflict &context)
+    // idx is the index of a reducible item. That item can be reached as
+    // context.d_itemVector[idx]
+void SRConflict::visitReduction(size_t reducibleIdx, SRConflict &context)
 {
     auto nextIter = context.d_nextVector.begin();
+    auto reducibleLAset = context.d_itemVector[reducibleIdx].lookaheadSet();
 
     while (true)
     {
-        nextIter =                  // check whether the a nextVector symbol
+        nextIter =                  // check whether a nextVector symbol
             find_if(                // is in the reduction item's LA set.
                 nextIter, context.d_nextVector.end(), 
-                FnWrap::unary(
-                    Next::inLAset, context.d_itemVector[idx].lookaheadSet())
+                FnWrap::unary(Next::inLAset, reducibleLAset)
             );
 
         if (nextIter == context.d_nextVector.end())
             return;
-
-        context.processShiftReduceConflict(nextIter, idx);
+        
+        context.processShiftReduceConflict(nextIter, reducibleIdx);
         ++nextIter;
     }
 }
+
+
+
+
+
+
+
+
